==> silverjuke_16.5.3.orig.tar.gz: silverjuke-16.5.3/CHANGES.md <==
Silverjuke Changes
================================================================================

V16.5.x (27.05.2016)
================================================================================

- New options to add UPnP/DLNA servers to the music library
- Ask before interrupting tracks
- Cleanup caches on music library updates
- Allow writing files via scripts
- Bug fixes


V16.3.x (17.03.2016)
================================================================================

- New Equalizer
- New prelistening options: Mix, Left/Right channel, Explicit output
- New prelistening overlay
- New video screen overlay showing the covers and the title
- New: Include/Exclude extensions in the source settings
- Option to show only a single channel added to the Spectrum monitor
- Add about 200 new handpicked visualization presets
- The visualization preset path is logged to the console window
- The first usage of the scripting engine is logged to the console window
- Bug fixes


V16.2.x (14.02.2016)
================================================================================

- New: Native support for "projectM", a Milkdrop-esque visualization
- New "Video screen" menu with direct access to all relating options
- New: Video support for Linux
- New: "Crossfading" and "Automatic Volume" for Linux, Mac and Windows
- For the linux port, GSteamer is used by default
- The video screen is closed if another view is selected or by a simple click
- New command line option "--blackrect" to cover unused areas
- Bug fixes


V16.1.x (12.01.2016)
================================================================================

- New: Mac OS X version
- New: Scripting and plugin-interface enabled by default
- New: Play Opus-files if possible
- New: INI-Switch to prepend zeros to track numbers, see file "user-guide"
- New: Read Winamp 5.6 genres
- New mouse wheel options at "Settings / Advanced"
- Show a warning before scripts are executed in Skins or via Drag'n'Drop
- All menu entries added by scripts go to the same place in the "Edit" menu
- Album view", "Cover view" and "List view" options in view menu
- Make "Skip Silence between tracks" work on Mac and Windows
- Bug fixes


V15.10.x (05.12.2015)
================================================================================

- New "Resume" options at "Settings / Playback"
- New "Jingle" options at "Settings / Playback"
- New: Read and write ratings from MP3, MPC, FLAC and OGG-files
- New: "Columns" and "Display" options in view menu
- New "Shortcuts" page in the advanced settings
- Bug fixes


V15.9.x (13.11.2015)
================================================================================

- New: "Limit Play Time" option
- New: The settings dialog opens with most recent page used
- New: INI-Switch "debug", see file "user-guide"
- Dialog "Automatic control/Further options" moved to a page in the main dialog
- Menu and settings dialog cleanup
- Bug fixes


V15.8.x (27.10.2015)
================================================================================

- Play non-DRM AAC- and ALAC-m4a-files if supported by the operating system
- Bug fixes


V15.6.x (14.10.2015)
================================================================================

- New: Add three more default skins
- New: Option to browse the help files locally
- Update artist info and cover search  URLs
- Bug fixes


V15.4.x (26.06.2015)
================================================================================

- New Silverjuke version based upon the open source core,
  see github.com/r10s/silverjuke


Copyright (c) Bjoern Petersen Software Design and Development,
http://b44t.com and contributors.

==> silverjuke_18.2.1.orig.tar.gz: silverjuke-18.2.1/CHANGES.md <==
Silverjuke Changes
================================================================================


V18.2.x (06.02.2018)
================================================================================

- Increase default image cache size
- Update Spanish translation
- Bug fixes


V16.5.x (27.05.2016)
================================================================================

- New options to add UPnP/DLNA servers to the music library
- Ask before interrupting tracks
- Cleanup caches on music library updates
- Allow writing files via scripts
- Bug fixes


V16.3.x (17.03.2016)
================================================================================

- New Equalizer
- New prelistening options: Mix, Left/Right channel, Explicit output
- New prelistening overlay
- New video screen overlay showing the covers and the title
- New: Include/Exclude extensions in the source settings
- Option to show only a single channel added to the Spectrum monitor
- Add about 200 new handpicked visualization presets
- The visualization preset path is logged to the console window
- The first usage of the scripting engine is logged to the console window
- Bug fixes


V16.2.x (14.02.2016)
================================================================================

- New: Native support for "projectM", a Milkdrop-esque visualization
- New "Video screen" menu with direct access to all relating options
- New: Video support for Linux
- New: "Crossfading" and "Automatic Volume" for Linux, Mac and Windows
- For the linux port, GSteamer is used by default
- The video screen is closed if another view is selected or by a simple click
- New command line option "--blackrect" to cover unused areas
- Bug fixes


V16.1.x (12.01.2016)
================================================================================

- New: Mac OS X version
- New: Scripting and plugin-interface enabled by default
- New: Play Opus-files if possible
- New: INI-Switch to prepend zeros to track numbers, see file "user-guide"
- New: Read Winamp 5.6 genres
- New mouse wheel options at "Settings / Advanced"
- Show a warning before scripts are executed in Skins or via Drag'n'Drop
- All menu entries added by scripts go to the same place in the "Edit" menu
- Album view", "Cover view" and "List view" options in view menu
- Make "Skip Silence between tracks" work on Mac and Windows
- Bug fixes


V15.10.x (05.12.2015)
================================================================================

- New "Resume" options at "Settings / Playback"
- New "Jingle" options at "Settings / Playback"
- New: Read and write ratings from MP3, MPC, FLAC and OGG-files
- New: "Columns" and "Display" options in view menu
- New "Shortcuts" page in the advanced settings
- Bug fixes


V15.9.x (13.11.2015)
================================================================================

- New: "Limit Play Time" option
- New: The settings dialog opens with most recent page used
- New: INI-Switch "debug", see file "user-guide"
- Dialog "Automatic control/Further options" moved to a page in the main dialog
- Menu and settings dialog cleanup
- Bug fixes


V15.8.x (27.10.2015)
================================================================================

- Play non-DRM AAC- and ALAC-m4a-files if supported by the operating system
- Bug fixes


V15.6.x (14.10.2015)
================================================================================

- New: Add three more default skins
- New: Option to browse the help files locally
- Update artist info and cover search  URLs
- Bug fixes


V15.4.x (26.06.2015)
================================================================================

- New Silverjuke version based upon the open source core,
  see github.com/r10s/silverjuke
